use std::sync::Arc;

use serde::{Deserialize, Serialize};
use validation::Validation;

mod validation;

#[derive(Deserialize, Serialize)]
pub struct Parameter {
    name: Arc<str>,
    data_type: DataType,
    is_array: bool,
    aliases: Vec<Arc<str>>,
    description: Option<Arc<str>>,
    help_message: Option<Arc<str>>,
    parameter_sets: Vec<ParameterSet>,
    validations: Vec<Validation>,
}

#[derive(Deserialize, Serialize)]
pub struct ParameterSet {
    name: Arc<str>,
    mandatory: bool,
    position: Option<u8>,
    value_from_pipeline: Option<bool>,
    value_from_pipeline_by_property_name: Option<bool>,
}

#[derive(Deserialize, Serialize)]
pub enum DataType {
    String,
    Int32,
    Int64,
    Switch,
    Bool,
    Credential,
    SecureString,
}
